# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Sub-Install
Version:	0.928
Release:	9.%{__distinit}%{__distvers}
Summary:	Install subroutines into packages easily
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Sub-Install/
Source0:	http://www.cpan.org/authors/id/R/RJ/RJBS/Sub-Install-%{version}.tar.gz
Patch1:		Sub-Install-0.927-tm088.patch
Patch2:		Sub-Install-0.928-tm082.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# ================= Module Build ============================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# ================= Run-time ================================
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# ================= Test Suite ==============================
BuildRequires:	perl(Test::More)
%if 0%{!?perl_bootstrap:1}
# Test::Output → Sub::Exporter → Sub::Install
BuildRequires:	perl(Test::Output)
%endif
BuildRequires:	perl(Test::Pod) >= 1.41
# ================= Run-time ================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This module makes it easy to install subroutines into packages without the
unsightly mess of no strict or typeglobs lying about where just anyone
can see them.

%prep
%setup -q -n Sub-Install-%{version}

# We need to patch the test suite if we have an old version of Test::More
# done_testing requires Test::More ≥ 0.88
%if %{old_test_more}
%patch1
%endif
# note requires Test::More ≥ 0.82
%if %{older_test_more}
%patch2
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Sub/
%{_mandir}/man3/Sub::Install.3*

%changelog
* Tue Sep 27 2016 Paul Howarth <paul@city-fan.org> - 0.928-9
- BR: perl-generators where available
- Simplify find command using -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.928-2
- Use %%license where possible

* Fri Jun 27 2014 Paul Howarth <paul@city-fan.org> - 0.928-1
- Update to 0.928
  - Cope with subroutines with spaces in their names when catching warnings
  - Don't assume that the source sub isn't blessed in tests (!)
- Update patches as needed
- Drop support for old distributions prior to FC-5
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch for building with ExtUtils::MakeMaker < 6.30

* Wed Oct 16 2013 Paul Howarth <paul@city-fan.org> - 0.927-1
- Update to 0.927
  - Rebuild using Dist::Zilla, update links to repo, metadata, etc.
  - Typo fixes
- Add patches to support building with ExtUtils::MakeMaker < 6.30 and
  Test::More < 0.94
- Explicitly run the extra tests
- Specify all dependencies

* Thu Aug 23 2012 Paul Howarth <paul@city-fan.org> - 0.926-6
- Classify buildreqs by usage

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.926-3
- Perl 5.16 post-bootstrap rebuild

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 0.926-2
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - All supported distributions have perl(Perl::Critic)
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sun Feb 26 2012 Paul Howarth <paul@city-fan.org> - 0.926-1
- Update to 0.926
  - Cope with terminal dots from new Carp
- BR: perl(Carp), perl(ExtUtils::MakeMaker) and perl(Scalar::Util)
- Package the LICENSE file

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 0.925-10
- Don't BR: perl(Test::Perl::Critic) if we're bootstrapping

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 0.925-9
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.925-5
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 31 2010 Paul Howarth <paul@city-fan.org> - 0.925-4
- Fix dist tag for RHEL-6 Beta

* Wed Mar  3 2010 Paul Howarth <paul@city-fan.org> - 0.925-3
- Reinstate perl(Test::Perl::Critic) buildreq
- Add buildreq perl(Test::Output), needed for tests on old distributions
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> - 0.925-2
- Define RPM macros in global scope
- Remove comments about Test::Output, no longer seem valid

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.925-1
- Update to 0.925

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 0.924-4
- Import from Fedora
- Drop perl(Test::Perl::Critic) buildreq for now - too many new packages to
  build today!

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.924-3
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.924-2
- Rebuild for new perl
- Fix license tag

* Wed Nov 22 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.924-1
- Update to 0.924
- Add perl(Test::Perl::Critic) to BR's

* Wed Sep 06 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.922-2
- Bump

* Sat Sep 02 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.922-1
- Specfile autogenerated by cpanspec 1.69.1
